==> lowcode-react-render-1.0.0.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _Loading from "@alifd/next/es/loading";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useState } from 'react';
import mergeWith from 'lodash/mergeWith';
import isArray from 'lodash/isArray';
import { buildComponents, assetBundle, AssetLevel, AssetLoader } from '@alilc/lowcode-utils';
import ReactRenderer from '@alilc/lowcode-react-renderer';
import { injectComponents } from '@alilc/lowcode-plugin-inject';
import appHelper from './appHelper';
import { getProjectSchemaFromLocalStorage, getPackagesFromLocalStorage, getPreviewLocale, setPreviewLocale } from './services/mockService';
var getScenarioName = function getScenarioName() {
  if (location.search) {
    return new URLSearchParams(location.search.slice(1)).get('scenarioName') || 'general';
  }
  return 'general';
};
var SamplePreview = function SamplePreview() {
  var _useState = useState({}),
    data = _useState[0],
    setData = _useState[1];
  function init() {
    return _init.apply(this, arguments);
  }
  function _init() {
    _init = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var scenarioName, packages, projectSchema, componentsMapArray, componentsTree, i18n, projectDataSource, componentsMap, pageSchema, libraryMap, libraryAsset, vendors, assetLoader, components;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            scenarioName = getScenarioName();
            packages = getPackagesFromLocalStorage(scenarioName);
            projectSchema = getProjectSchemaFromLocalStorage(scenarioName);
            componentsMapArray = projectSchema.componentsMap, componentsTree = projectSchema.componentsTree, i18n = projectSchema.i18n, projectDataSource = projectSchema.dataSource;
            componentsMap = {};
            componentsMapArray.forEach(function (component) {
              componentsMap[component.componentName] = component;
            });
            pageSchema = componentsTree[0];
            libraryMap = {};
            libraryAsset = [];
            packages.forEach(function (_ref2) {
              var _package = _ref2["package"],
                library = _ref2.library,
                urls = _ref2.urls,
                renderUrls = _ref2.renderUrls;
              libraryMap[_package] = library;
              if (renderUrls) {
                libraryAsset.push(renderUrls);
              } else if (urls) {
                libraryAsset.push(urls);
              }
            });
            vendors = [assetBundle(libraryAsset, AssetLevel.Library)]; // TODO asset may cause pollution
            assetLoader = new AssetLoader();
            _context.next = 14;
            return assetLoader.load(libraryAsset);
          case 14:
            _context.next = 16;
            return injectComponents(buildComponents(libraryMap, componentsMap));
          case 16:
            components = _context.sent;
            setData({
              schema: pageSchema,
              components: components,
              i18n: i18n,
              projectDataSource: projectDataSource
            });
          case 18:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return _init.apply(this, arguments);
  }
  var _ref = data,
    schema = _ref.schema,
    components = _ref.components,
    _ref$i18n = _ref.i18n,
    i18n = _ref$i18n === void 0 ? {} : _ref$i18n,
    _ref$projectDataSourc = _ref.projectDataSource,
    projectDataSource = _ref$projectDataSourc === void 0 ? {} : _ref$projectDataSourc;
  if (!schema || !components) {
    init();
    return /*#__PURE__*/React.createElement(_Loading, {
      fullScreen: true
    });
  }
  var currentLocale = getPreviewLocale(getScenarioName());
  if (!window.setPreviewLocale) {
    // for demo use only, can use this in console to switch language for i18n test
    // 在控制台 window.setPreviewLocale('en-US') 或 window.setPreviewLocale('zh-CN') 查看切换效果
    window.setPreviewLocale = function (locale) {
      return setPreviewLocale(getScenarioName(), locale);
    };
  }
  function customizer(objValue, srcValue) {
    if (isArray(objValue)) {
      return objValue.concat(srcValue || []);
    }
  }
  return /*#__PURE__*/React.createElement("div", {
    className: "lowcode-plugin-sample-preview"
  }, /*#__PURE__*/React.createElement(ReactRenderer, {
    className: "lowcode-plugin-sample-preview-content",
    schema: _extends({}, schema, {
      dataSource: mergeWith(schema.dataSource, projectDataSource, customizer)
    }),
    components: components,
    locale: currentLocale,
    messages: i18n,
    appHelper: appHelper
  }));
};
export default SamplePreview;

==> lowcode-react-render-1.0.2.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import ReactDOM from 'react-dom';
import React, { useState } from 'react';
import mergeWith from 'lodash/mergeWith';
import isArray from 'lodash/isArray';
import { buildComponents, assetBundle, AssetLevel, AssetLoader } from '@alilc/lowcode-utils';
import ReactRenderer from '@alilc/lowcode-react-renderer';
import { injectComponents } from '@alilc/lowcode-plugin-inject';
import appHelper from './appHelper';
import { getProjectSchemaFromLocalStorage, getPackagesFromLocalStorage, getPreviewLocale, setPreviewLocale } from './services/mockService';
import { deleteObjectProperty } from './utils';
var SamplePreview = function SamplePreview() {
  var _useState = useState({}),
    data = _useState[0],
    setData = _useState[1];
  function init() {
    return _init.apply(this, arguments);
  }
  function _init() {
    _init = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var scenarioName, packages, projectSchema, componentsMapArray, componentsTree, i18n, projectDataSource, componentsMap, pageSchema, libraryMap, libraryAsset, vendors, assetLoader, components;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            scenarioName = 'general';
            packages = getPackagesFromLocalStorage(scenarioName);
            projectSchema = getProjectSchemaFromLocalStorage(scenarioName);
            componentsMapArray = projectSchema.componentsMap, componentsTree = projectSchema.componentsTree, i18n = projectSchema.i18n, projectDataSource = projectSchema.dataSource;
            componentsMap = {};
            componentsMapArray.forEach(function (component) {
              componentsMap[component.componentName] = component;
            });
            pageSchema = componentsTree[0];
            libraryMap = {};
            libraryAsset = [];
            packages.forEach(function (_ref2) {
              var _package = _ref2["package"],
                library = _ref2.library,
                urls = _ref2.urls,
                renderUrls = _ref2.renderUrls;
              libraryMap[_package] = library;
              if (renderUrls) {
                libraryAsset.push(renderUrls);
              } else if (urls) {
                libraryAsset.push(urls);
              }
            });
            vendors = [assetBundle(libraryAsset, AssetLevel.Library)]; // TODO asset may cause pollution
            assetLoader = new AssetLoader();
            _context.next = 14;
            return assetLoader.load(libraryAsset);
          case 14:
            _context.next = 16;
            return injectComponents(buildComponents(libraryMap, componentsMap));
          case 16:
            components = _context.sent;
            setData({
              schema: pageSchema,
              components: components,
              i18n: i18n,
              projectDataSource: projectDataSource
            });
          case 18:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return _init.apply(this, arguments);
  }
  var _ref = data,
    schema = _ref.schema,
    components = _ref.components,
    _ref$i18n = _ref.i18n,
    i18n = _ref$i18n === void 0 ? {} : _ref$i18n,
    _ref$projectDataSourc = _ref.projectDataSource,
    projectDataSource = _ref$projectDataSourc === void 0 ? {} : _ref$projectDataSourc;
  if (!schema || !components) {
    init();
    return '';
  }
  var currentLocale = getPreviewLocale(getScenarioName());
  if (!window.setPreviewLocale) {
    // for demo use only, can use this in console to switch language for i18n test
    // 在控制台 window.setPreviewLocale('en-US') 或 window.setPreviewLocale('zh-CN') 查看切换效果
    window.setPreviewLocale = function (locale) {
      return setPreviewLocale(getScenarioName(), locale);
    };
  }
  function customizer(objValue, srcValue) {
    if (isArray(objValue)) {
      return objValue.concat(srcValue || []);
    }
  }
  return /*#__PURE__*/React.createElement("div", {
    className: "lowcode-plugin-sample-preview"
  }, /*#__PURE__*/React.createElement(ReactRenderer, {
    className: "lowcode-plugin-sample-preview-content",
    schema: _extends({}, schema, {
      dataSource: mergeWith(schema.dataSource, projectDataSource, customizer)
    }),
    components: components,
    locale: currentLocale,
    messages: i18n,
    appHelper: appHelper,
    onCompGetRef: function onCompGetRef(schema, ref) {
      if (schema.componentName === 'FormContainer') {
        deleteObjectProperty(schemaRenderRef);
        Object.assign(schemaRenderRef, {
          schema: schema,
          ref: ref
        });
      }
    }
  }));
};
export default SamplePreview;
ReactDOM.render( /*#__PURE__*/React.createElement(SamplePreview, null), document.getElementById('ice-container'));
